@@ -10,14 +10,19 @@ def message_user(user, message, level=constants.INFO):
     :param message: Message to show
     :param level: Message level
     """
-    cache.set(_user_key(user), (message, level))
+    # We store a list of messages in the cache so we can have multiple messages
+    # queued up for a user.
+    user_key = _user_key(user)
+    messages = cache.get(user_key) or []
+    messages.append((message, level))
+    cache.set(user_key, messages)
 
 
 def message_users(users, message, level=constants.INFO):
     """
     Send a message to a group of users.
 
-    :param users: Users queryset 
+    :param users: Users queryset
     :param message: Message to show
     :param level: Message level
     """
@@ -25,9 +30,9 @@ def message_users(users, message, level=constants.INFO):
         message_user(user, message, level)
 
 
-def get_message(user):
+def get_messages(user):
     """
-    Fetch a message for given user.  Returns None if no such message exists.
+    Fetch messages for given user.  Returns None if no such message exists.
 
     :param user: User instance
     """
@@ -35,8 +40,8 @@ def get_message(user):
     result = cache.get(key)
     if result:
         cache.delete(key)
-        return result[0], result[1]
-    return None, None
+        return result
+    return None
 
 
 def _user_key(user):
